@@ -1,7 +1,7 @@
 package PowerManagement::Any;
 
 our $DATE = '2019-05-22'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,7 +48,7 @@ sub _target_is_masked {
     [200, "OK", $is_masked];
 }
 
-sub _prevent_or_unprevent_sleep {
+sub _prevent_or_unprevent_sleep_or_check {
     my ($which, %args) = @_;
 
   SYSTEMD:
@@ -70,6 +70,7 @@ sub _prevent_or_unprevent_sleep {
             return $res;
         }
         $is_masked = $res->[2];
+        return [200, "OK", $is_masked] if $which eq 'check';
         return [304, "sleep.target already masked"]
             if $which eq 'prevent' && $is_masked;
         return [304, "sleep.target already unmasked"]
@@ -122,7 +123,7 @@ _
     args => {},
 };
 sub prevent_sleep {
-    _prevent_or_unprevent_sleep('prevent', @_);
+    _prevent_or_unprevent_sleep_or_check('prevent', @_);
 }
 
 $SPEC{'unprevent_sleep'} = {
@@ -136,7 +137,21 @@ _
     args => {},
 };
 sub unprevent_sleep {
-    _prevent_or_unprevent_sleep('unprevent', @_);
+    _prevent_or_unprevent_sleep_or_check('unprevent', @_);
+}
+
+$SPEC{'sleep_is_prevented'} = {
+    v => 1.1,
+    summary => 'Check if sleep has been prevented',
+    description => <<'_',
+
+See `prevent_sleep()` for more details.
+
+_
+    args => {},
+};
+sub sleep_is_prevented {
+    _prevent_or_unprevent_sleep_or_check('check', @_);
 }
 
 1;
@@ -154,7 +169,7 @@ PowerManagement::Any - Common interface to some power management tasks
 
 =head1 VERSION
 
-This document describes version 0.001 of PowerManagement::Any (from Perl distribution PowerManagement-Any), released on 2019-05-22.
+This document describes version 0.002 of PowerManagement::Any (from Perl distribution PowerManagement-Any), released on 2019-05-22.
 
 =head1 NOTES
 
@@ -198,6 +213,33 @@ Return value:  (any)
 
 
 
+=head2 sleep_is_prevented
+
+Usage:
+
+ sleep_is_prevented() -> [status, msg, payload, meta]
+
+Check if sleep has been prevented.
+
+See C<prevent_sleep()> for more details.
+
+This function is not exported by default, but exportable.
+
+No arguments.
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 unprevent_sleep
 
 Usage:
